@@ -11,7 +11,6 @@ from databuilder.extractor.dashboard.mode_analytics.mode_dashboard_executions_ex
 from databuilder.extractor.dashboard.mode_analytics.mode_dashboard_utils import ModeDashboardUtils
 from databuilder.extractor.restapi.rest_api_extractor import STATIC_RECORD_DICT
 from databuilder.rest_api.mode_analytics.mode_paginated_rest_api_query import ModePaginatedRestApiQuery
-from databuilder.rest_api.rest_api_query import RestApiQuery
 from databuilder.transformer.dict_to_model import MODEL_CLASS, DictToModel
 from databuilder.transformer.timestamp_string_to_epoch import FIELD_NAME, TimestampStringToEpoch
 
@@ -42,23 +41,25 @@ class ModeDashboardLastModifiedTimestampExtractor(ModeDashboardExecutionsExtract
     def get_scope(self) -> str:
         return 'extractor.mode_dashboard_last_modified_timestamp_execution'
 
-    def _build_restapi_query(self) -> RestApiQuery:
+    def _build_restapi_query(self) -> ModePaginatedRestApiQuery:
         """
-        Build REST API Query. To get Mode Dashboard last modified timestamp, it needs to call two APIs (spaces API,
-        and reports API) joining together.
+        Build REST API Query to get Mode Dashboard last modified timestamp
         :return: A RestApiQuery that provides Mode Dashboard last successful execution (run)
         """
 
-        spaces_query = ModeDashboardUtils.get_spaces_query_api(conf=self._conf)
-        params = ModeDashboardUtils.get_auth_params(conf=self._conf)
+        seed_query = ModeDashboardUtils.get_seed_query(conf=self._conf)
+        params = ModeDashboardUtils.get_auth_params(conf=self._conf, discover_auth=True)
 
         # Reports
-        # https://mode.com/developer/api-reference/analytics/reports/#listReportsInSpace
-        url = 'https://app.mode.com/api/{organization}/spaces/{dashboard_group_id}/reports'
-        json_path = '_embedded.reports[*].[token,edited_at]'
-        field_names = ['dashboard_id', 'last_modified_timestamp']
-        last_modified_query = ModePaginatedRestApiQuery(query_to_join=spaces_query, url=url, params=params,
+        # https://mode.com/developer/discovery-api/analytics/reports/
+        url = 'https://app.mode.com/batch/{organization}/reports'
+        json_path = 'reports[*].[token, space_token, edited_at]'
+        field_names = ['dashboard_id', 'dashboard_group_id', 'last_modified_timestamp']
+        max_record_size = 1000
+        pagination_json_path = 'reports[*]'
+        last_modified_query = ModePaginatedRestApiQuery(query_to_join=seed_query, url=url, params=params,
                                                         json_path=json_path, field_names=field_names,
-                                                        skip_no_result=True)
+                                                        skip_no_result=True, max_record_size=max_record_size,
+                                                        pagination_json_path=pagination_json_path)
 
         return last_modified_query
